Crate monoutils_store

Crate monoutils_store 

monoutils-store is a library for working with IPLD content-addressed stores (CAS).

Modules

ipld
Re-exports of the libipld crate.

Structs

AnyError
An error that can represent any error.
DualStore
A dual store that stores blocks on two different stores.
DualStoreConfig
Configuration for a dual store.
FixedSizeChunker
FixedSizeChunker splits data into fixed-size chunks, regardless of the content, in a simple and deterministic.
FlatLayout
A layout that organizes data into a flat array of chunks with a single merkle node parent.
FlatLayoutReader
A reader for the flat DAG layout.
MemoryStore
An in-memory storage for IPLD node and raw blocks with reference counting.
MerkleNode
A MerkleNode is a simple data structure for constructing a Directed Acyclic Graph (DAG) out of multiple leaf data.
PlaceholderStore
A placeholder store that does nothing. It is meant to be used as a placeholder for a store that is not yet implemented.
RabinChunker
A chunker that splits data into variable-size chunks using the Rabin fingerprinting algorithm.

Enums

Choice
Choices for selecting which store to use for a given operation.
Codec
The different codecs supported by the IPLD store.
LayoutError
An error that occurred during a layout operation.
StoreError
An error that occurred during a file system operation.

Constants

DEFAULT_CHUNK_MAX_SIZE
The default chunk size is 512 KiB.

Traits

Chunker
A chunker that splits incoming bytes into chunks and returns those chunks as a stream.
IpldReferences
A trait for types that can hold CID references to some data.
IpldStore
IpldStore is a content-addressable store for IPLD (InterPlanetary Linked Data) that emphasizes the structured nature of the data it stores.
IpldStoreExt
Helper extension to the IpldStore trait.
IpldStoreSeekable
IpldStoreSeekable is a trait that extends the IpldStore trait to allow for seeking.
Layout
A layout strategy for organizing a stream of chunks into a graph of blocks.
LayoutSeekable
A trait that extends the Layout trait to allow for seeking.
SeekableReader
A trait that extends the AsyncRead and AsyncSeek traits to allow for seeking.
Storable
A trait that all types that need to be stored in an IPLD store must implement.

Functions

Ok
Creates an Ok FsResult d.

Type Aliases

StoreResult
The result of a file system operation.