pub enum StoreError {
BlockNotFound(Cid),
NodeBlockTooLarge(u64, u64),
RawBlockTooLarge(u64, u64),
UnsupportedCodec(u64),
UnexpectedBlockCodec(Codec, Codec),
Custom(AnyError),
LayoutError(LayoutError),
}Expand description
An error that occurred during a file system operation.
Variants
BlockNotFound(Cid)
The block was not found.
NodeBlockTooLarge(u64, u64)
The node block is too large.
RawBlockTooLarge(u64, u64)
The raw block is too large.
UnsupportedCodec(u64)
Codec not supported.
UnexpectedBlockCodec(Codec, Codec)
Expected block codec does not match the actual codec.
Custom(AnyError)
Custom error.
LayoutError(LayoutError)
Layout error.
Implementations
Sourceimpl StoreError
impl StoreError
Sourcepub fn custom(error: impl Into<Error>) -> StoreError
pub fn custom(error: impl Into<Error>) -> StoreError
Creates a new Err result.