DualStore

Struct DualStore 

pub struct DualStore<A, B>
where A: IpldStore, B: IpldStore,
{ /* private fields */ }
A dual store that stores blocks on two different stores.

Implementations

Source

impl<A, B> DualStore<A, B>
where A: IpldStore, B: IpldStore,

pub fn new(store_a: A, store_b: B, config: DualStoreConfig) -> Self

Creates a new dual store from two stores.

pub async fn get_node_from<D>( &self, cid: &Cid, choice: Choice, ) -> StoreResult<D>

Gets the type stored as an IPLD data from a chosen store by its Cid.

pub async fn get_bytes_from<'a>( &'a self, cid: &'a Cid, choice: Choice, ) -> StoreResult<Pin<Box<dyn AsyncRead + Send + Sync + 'a>>>

Gets the bytes stored in a chosen store as raw bytes by its Cid.

pub async fn get_raw_block_from( &self, cid: &Cid, choice: Choice, ) -> StoreResult<Bytes>

Gets raw bytes from a chosen store as a single block by its Cid.

pub async fn put_node_into<T>( &self, data: &T, choice: Choice, ) -> StoreResult<Cid>

Saves a serializable type to a chosen store and returns the Cid to it.

pub async fn put_bytes_into( &self, bytes: impl AsyncRead + Send + Sync, choice: Choice, ) -> StoreResult<Cid>

Saves raw bytes to a chosen store and returns the Cid to it.

pub async fn put_raw_block_into( &self, bytes: impl Into<Bytes> + Send, choice: Choice, ) -> StoreResult<Cid>

Saves raw bytes as a single block to a chosen store and returns the Cid to it.

pub async fn has_from(&self, cid: &Cid, choice: Choice) -> bool

Checks if a block exists in a chosen store by its Cid.