pub struct FlatLayoutReader<S>where
S: IpldStore,{ /* private fields */ }Expand description
A reader for the flat DAG layout.
The reader maintains three state variables:
- The current byte position,
byte_cursor. - The index of the current chunk within the node’s children array,
chunk_index. - The distance (in bytes) of the current chunk index from the start,
chunk_distance.
These state variables are used to determine the current chunk to read from and the byte position within the chunk to read from. It basically enables seeking to any byte position within the chunk array.
Chunk Index = 1
Chunk Distance = 3
│
│
0 ▼ 1 2
┌──┬──┬──┐ ┌──┬──┬──┬──┬──┐ ┌──┬──┬──┬──┐
│0 │1 │2 │ │3 │4 │5 │6 │7 │ │8 │9 │10│11│
└──┴──┴──┘ └──┴──┴──┴──┴──┘ └──┴──┴──┴──┘
▲
│
│
Byte Cursor = 5Trait Implementations
Sourceimpl<S> AsyncRead for FlatLayoutReader<S>
impl<S> AsyncRead for FlatLayoutReader<S>
Sourceimpl<S> AsyncSeek for FlatLayoutReader<S>
impl<S> AsyncSeek for FlatLayoutReader<S>