MemoryStore

Struct MemoryStore 

pub struct MemoryStore<C = FixedSizeChunker, L = FlatLayout>
where C: Chunker, L: Layout,
{ /* private fields */ }
An in-memory storage for IPLD node and raw blocks with reference counting.

This store maintains a reference count for each stored block. Reference counting is used to determine when a block can be safely removed from the store.

Implementations

Source

impl<C, L> MemoryStore<C, L>
where C: Chunker, L: Layout,

pub fn new(chunker: C, layout: L) -> Self

Creates a new MemoryStore with the given chunker and layout.

pub fn debug(&self)
where C: Clone + Send, L: Clone + Send,

Prints all the blocks in the store.