monoutils-store is a library for working with IPLD content-addressed stores (CAS).
Modules
- ipld
- Re-exports of the
libipldcrate.
Structs
- AnyError
- An error that can represent any error.
- Dual
Store - A dual store that stores blocks on two different stores.
- Dual
Store Config - Configuration for a dual store.
- Fixed
Size Chunker FixedSizeChunkersplits data into fixed-size chunks, regardless of the content, in a simple and deterministic.- Flat
Layout - A layout that organizes data into a flat array of chunks with a single merkle node parent.
- Flat
Layout Reader - A reader for the flat DAG layout.
- Memory
Store - An in-memory storage for IPLD node and raw blocks with reference counting.
- Merkle
Node - A
MerkleNodeis a simple data structure for constructing a Directed Acyclic Graph (DAG) out of multiple leaf data. - Placeholder
Store - A placeholder store that does nothing. It is meant to be used as a placeholder for a store that is not yet implemented.
- Rabin
Chunker - A chunker that splits data into variable-size chunks using the Rabin fingerprinting algorithm.
Enums
- Choice
- Choices for selecting which store to use for a given operation.
- Codec
- The different codecs supported by the IPLD store.
- Layout
Error - An error that occurred during a layout operation.
- Store
Error - An error that occurred during a file system operation.
Constants
- DEFAULT_
CHUNK_ MAX_ SIZE - The default chunk size is 512 KiB.
Traits
- Chunker
- A chunker that splits incoming bytes into chunks and returns those chunks as a stream.
- Ipld
References - A trait for types that can hold CID references to some data.
- Ipld
Store IpldStoreis a content-addressable store forIPLD(InterPlanetary Linked Data) that emphasizes the structured nature of the data it stores.- Ipld
Store Ext - Helper extension to the
IpldStoretrait. - Ipld
Store Seekable IpldStoreSeekableis a trait that extends theIpldStoretrait to allow for seeking.- Layout
- A layout strategy for organizing a stream of chunks into a graph of blocks.
- Layout
Seekable - A trait that extends the
Layouttrait to allow for seeking. - Seekable
Reader - A trait that extends the
AsyncReadandAsyncSeektraits to allow for seeking. - Storable
- A trait that all types that need to be stored in an IPLD store must implement.
Functions
- Ok
- Creates an
OkFsResultd.
Type Aliases
- Store
Result - The result of a file system operation.