pub struct DualStore<A, B>{ /* private fields */ }Expand description
A dual store that stores blocks on two different stores.
Implementations
Sourceimpl<A, B> DualStore<A, B>
impl<A, B> DualStore<A, B>
Sourcepub fn new(store_a: A, store_b: B, config: DualStoreConfig) -> Self
pub fn new(store_a: A, store_b: B, config: DualStoreConfig) -> Self
Creates a new dual store from two stores.
Sourcepub async fn get_node_from<D>(
&self,
cid: &Cid,
choice: Choice,
) -> StoreResult<D>where
D: DeserializeOwned + Send,
pub async fn get_node_from<D>(
&self,
cid: &Cid,
choice: Choice,
) -> StoreResult<D>where
D: DeserializeOwned + Send,
Gets the type stored as an IPLD data from a chosen store by its Cid.
Sourcepub async fn get_bytes_from<'a>(
&'a self,
cid: &'a Cid,
choice: Choice,
) -> StoreResult<Pin<Box<dyn AsyncRead + Send + Sync + 'a>>>
pub async fn get_bytes_from<'a>( &'a self, cid: &'a Cid, choice: Choice, ) -> StoreResult<Pin<Box<dyn AsyncRead + Send + Sync + 'a>>>
Gets the bytes stored in a chosen store as raw bytes by its Cid.
Sourcepub async fn get_raw_block_from(
&self,
cid: &Cid,
choice: Choice,
) -> StoreResult<Bytes>
pub async fn get_raw_block_from( &self, cid: &Cid, choice: Choice, ) -> StoreResult<Bytes>
Gets raw bytes from a chosen store as a single block by its Cid.
Sourcepub async fn put_node_into<T>(
&self,
data: &T,
choice: Choice,
) -> StoreResult<Cid>
pub async fn put_node_into<T>( &self, data: &T, choice: Choice, ) -> StoreResult<Cid>
Saves a serializable type to a chosen store and returns the Cid to it.
Sourcepub async fn put_bytes_into(
&self,
bytes: impl AsyncRead + Send + Sync,
choice: Choice,
) -> StoreResult<Cid>
pub async fn put_bytes_into( &self, bytes: impl AsyncRead + Send + Sync, choice: Choice, ) -> StoreResult<Cid>
Saves raw bytes to a chosen store and returns the Cid to it.
Sourcepub async fn put_raw_block_into(
&self,
bytes: impl Into<Bytes> + Send,
choice: Choice,
) -> StoreResult<Cid>
pub async fn put_raw_block_into( &self, bytes: impl Into<Bytes> + Send, choice: Choice, ) -> StoreResult<Cid>
Saves raw bytes as a single block to a chosen store and returns the Cid to it.