pub struct FlatLayout {}Expand description
A layout that organizes data into a flat array of chunks with a single merkle node parent.
┌─────────────┐
│ Merkle Node │
└──────┬──────┘
│
┌───────────────┬──────┴────────┬─────────────────┐
│ │ │ │
0 ▼ 1 ▼ 2 ▼ 3 ▼
┌──┬──┬──┐ ┌──┬──┬──┬──┬──┐ ┌──┬──┬──┬──┐ ┌──┬──┬──┬──┬──┬──┐
│0 │1 │2 │ │3 │4 │5 │6 │7 │ │8 │9 │10│11│ │12│13│14│15│16│17│
└──┴──┴──┘ └──┴──┴──┴──┴──┘ └──┴──┴──┴──┘ └──┴──┴──┴──┴──┴──┘Implementations
Sourceimpl FlatLayout
impl FlatLayout