pub struct MemoryStore<C = FixedSizeChunker, L = FlatLayout>{ /* private fields */ }Expand description
An in-memory storage for IPLD node and raw blocks with reference counting.
This store maintains a reference count for each stored block. Reference counting is used to determine when a block can be safely removed from the store.
Implementations